@@ -110,3 +110,9 @@ def round_decimal_point_5(x):
 
 def format_chilean_int_point_and_coma(number):
     return "{:,}".format(number).replace(',', 'x').replace('.', ',').replace('x', '.')
+
+
+def datetime_now_tz_america_santiago():
+    tz = pytz.timezone('America/Santiago')
+    datetime_utc_to_arrow = arrow.get(timezone.now(), tz)
+    return datetime_utc_to_arrow.to(timezone).datetime
